@@ -1,16 +1,24 @@
 #include <QtGui/QApplication>
 #include "qmlapplicationviewer.h"
 #include <QDeclarativeEngine>
+#include <QDeclarativeContext>
+#include "Bunker.h"
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
+    qmlRegisterType<Bunker>("SpaceInvaders", 1, 0, "Bunker");
+
     QmlApplicationViewer viewer;
     viewer.setOrientation(QmlApplicationViewer::ScreenOrientationLockLandscape);
 
     viewer.engine()->addImportPath(QString("/opt/qtm11/imports"));
 
+    //BunkerFactory bunkerFactory;
+    //viewer.rootContext()->setContextProperty("bunkerFactory", &bunkerFactory);
+
+
     viewer.setMainQmlFile(QLatin1String("qml/pgz-spaceinvaders/main.qml"));
     viewer.showExpanded();
 
